summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:08 -0600
commit0683a2b517140969cdf0617600dc7efad2f1a325 (patch)
tree76e6da2ba7868e2d73bf91f110accbc7db5e06f9
parent115fcbe323837e49907d6897f28dd8c91dea3b6f (diff)
downloadkgtk-qt3-0683a2b5.tar.gz
kgtk-qt3-0683a2b5.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 115fcbe323837e49907d6897f28dd8c91dea3b6f.
-rw-r--r--kdialogd3/kdialogd.cpp4
-rw-r--r--tqt/kqt3.cpp20
2 files changed, 12 insertions, 12 deletions
diff --git a/kdialogd3/kdialogd.cpp b/kdialogd3/kdialogd.cpp
index f957a68..a0ca4db 100644
--- a/kdialogd3/kdialogd.cpp
+++ b/kdialogd3/kdialogd.cpp
@@ -471,7 +471,7 @@ void KDialogDClient::initDialog(const TQString &caption, KDialogBase *d, unsigne
KWin::setState(itsDlg->winId(), NET::Modal);
KWin::WindowInfo wi(KWin::windowInfo(xid, NET::WMGeometry, NET::WM2UserTime));
- TQRect geom(wi.geometry());
+ TQRect geom(wi.tqgeometry());
int rx=geom.x(),
ry=geom.y();
@@ -586,7 +586,7 @@ void KDialogDFileDialog::slotOk()
good=!KIO::NetAccess::exists(urls.first(), false, this) ||
KMessageBox::Continue==KMessageBox::warningContinueCancel(this,
i18n("File %1 exists.\nDo you want to replace it?")
- .arg(urls.first().prettyURL()),
+ .tqarg(urls.first().prettyURL()),
i18n("File Exists"),
KGuiItem(i18n("Replace"), "filesaveas"), TQString(),
KMessageBox::Notify|KMessageBox::PlainCaption);
diff --git a/tqt/kqt3.cpp b/tqt/kqt3.cpp
index 8ceb265..962f72a 100644
--- a/tqt/kqt3.cpp
+++ b/tqt/kqt3.cpp
@@ -188,7 +188,7 @@ static void kde2TQtFilter(const TQString &orig, TQString *sel)
// HACK HACK HACK!!!
// KGtk versions <=0.9.1 used this copied TQFileDialogPrivate to access the file filters
// newer versions walk the file dialogs children...
class TQFileDialogPrivate {
public:
~TQFileDialogPrivate();
@@ -224,12 +224,12 @@ static const TQString getFilters(TQFileDialog *dlg, bool scribusSave=false)
#else
if(dlg)
{
- const TQObjectList children=((TQObject *)dlg)->childrenListObject();
+ const TQObjectList tqchildren=((TQObject *)dlg)->childrenListObject();
- if(!children.isEmpty())
+ if(!tqchildren.isEmpty())
{
- TQObjectList::ConstIterator it(children.begin()),
- end(children.end());
+ TQObjectList::ConstIterator it(tqchildren.begin()),
+ end(tqchildren.end());
for(; it!=end; ++it)
if(::tqqt_cast<TQComboBox *>(*it) && 0==qstrcmp((*it)->name(), "file types"))
@@ -261,12 +261,12 @@ static TQString getCurrentFileName(TQFileDialog *dlg)
{
if(dlg)
{
- const TQObjectList children=((TQObject *)dlg)->childrenListObject();
+ const TQObjectList tqchildren=((TQObject *)dlg)->childrenListObject();
- if(!children.isEmpty())
+ if(!tqchildren.isEmpty())
{
- TQObjectList::ConstIterator it(children.begin()),
- end(children.end());
+ TQObjectList::ConstIterator it(tqchildren.begin()),
+ end(tqchildren.end());
for(; it!=end; ++it)
if(::tqqt_cast<TQLineEdit *>(*it)) // && 0==qstrcmp((*it)->name(), "name/filter editor"))
@@ -397,7 +397,7 @@ static bool sendMessage(TQWidget *parent, Operation op, TQStringList &res, TQStr
if(connectToKDialogD(getAppName()))
{
char o=(char)op;
- int xid=parent ? parent->topLevelWidget()->winId() : tqApp->activeWindow()->winId();
+ int xid=parent ? parent->tqtopLevelWidget()->winId() : tqApp->activeWindow()->winId();
if(writeBlock(kdialogdSocket, &o, 1) &&
writeBlock(kdialogdSocket, (char *)&xid, 4) &&
@@ -188,7 +188,7 @@ static void kde2TQtFilter(const TQString &orig, TQString *sel)
// HACK HACK HACK!!!
// KGtk versions <=0.9.1 used this copied TQFileDialogPrivate to access the file filters
-// newer versions walk the file dialogs children...
+// newer versions walk the file dialogs tqchildren...
class TQFileDialogPrivate {
public: